MemberEventKind

Enum MemberEventKind 

pub enum MemberEventKind {
    Initialized,
    MemberJoining,
    MemberUp,
    MemberUpdated,
    MemberUnreachable,
    MemberReachable,
    MemberLeaving,
    MemberExiting,
    MemberDown,
    MemberRemoved,
    MemberRejoined,
}
Kind of MemberEvent.

Variants



Initialized

Initial event held by the lossless subscription before the actor starts.



MemberJoining

Member entered Joining.



MemberUp

Member entered Up.



MemberUpdated

Member roles or advertised address changed without a state change.



MemberUnreachable

Member was marked unreachable by foca suspicion.



MemberReachable

Member became reachable again.



MemberLeaving

Member entered Leaving.



MemberExiting

Member entered Exiting.



MemberDown

Member entered Down.



MemberRemoved

Member entered Removed.



MemberRejoined

A down/removed logical node returned with a newer incarnation.