pub enum MemberState {
Joining,
Up,
Leaving,
Exiting,
Down,
Removed,
}Expand description
Akka-style member lifecycle state used by Datum membership.
Variants
Joining
The member has been discovered but is not yet considered available.
Up
The member is available for future control-plane decisions.
Leaving
The member requested a graceful leave.
Exiting
The member is exiting after a graceful leave was acknowledged.
Down
The member was downed after failure detection/downing.
Removed
The member has been removed from the active membership view.